<h1 align = "center">:rocket: 白话统计学 :facepunch:</h1>

---
- 协方差:

![协方差][1]

---
- Pearson相关系数

![Pearson相关系数][2]

---
[1]: https://gss2.bdstatic.com/9fo3dSag_xI4khGkpoWK1HF6hhy/baike/s%3D340/sign=6005955212dfa9ecf92e501352d1f754/359b033b5bb5c9ea8718f4add639b6003bf3b391.jpg
[2]: https://gss3.bdstatic.com/7Po3dSag_xI4khGkpoWK1HF6hhy/baike/s%3D153/sign=1337cb6aa1cc7cd9fe2d30dc0a002104/574e9258d109b3de231a34efcebf6c81810a4c94.jpg
